package com.ynet.life.sujrb.action;

import com.ynet.gene.core.Context;
import com.ynet.gene.core.GENEException;
import com.ynet.life.base.LifeAction;
import com.ynet.life.base.LifeStandard;
import com.ynet.life.base.Trace;
import com.ynet.life.exception.TranFailException;
import com.ynet.life.file.LifeFile;
import com.ynet.life.file.parser.CommonFileParserInterface;
import com.ynet.life.file.parser.CommonParserFactory;
import java.util.ArrayList;
import java.util.List;
import java.util.Map;
import java.util.Random;
import java.util.StringTokenizer;

/* loaded from: com_ynet_life_sujrb_action.jar:com/ynet/life/sujrb/action/ReportDownloadTitleAction.class */
public class ReportDownloadTitleAction extends LifeAction {
    private static final String FIELD_SEPERATOR = "||";
    protected String fileTypeField;
    protected String fileNameField;
    protected String titleField;
    protected String encoding;
    private List outputFields;
    private List titleColWidthFormats;
    private List leftRightColMergeFormats;
    private List leftRightColMergeNum;
    private List topBottomColMergeFormats;
    private List oneTitles;
    private List twoTitles;
    private String iCollName;
    private String reportType;

    public String execute(Context ctx) throws GENEException {
        try {
            ctx.terminate();
            List recordList = initFromContext(ctx, this.iCollName);
            String fileType = (String) ctx.get(this.fileTypeField);
            CommonFileParserInterface parser = CommonParserFactory.createParser(fileType);
            String filePathName = getFileName(fileType, this.fileNameField);
            String language = getLanguage(ctx);
            List oneTitlesI18N = new ArrayList();
            List twoTitlesI18N = new ArrayList();
            if (this.oneTitles != null) {
                for (int i = 0; i < this.oneTitles.size(); i++) {
                    oneTitlesI18N.add(LifeStandard.getResouceDisplayAt((String) this.oneTitles.get(i), language));
                }
                if (this.reportType.equals("0")) {
                    String month = String.valueOf(Integer.parseInt(((String) ctx.get("startDate")).substring(4, 6)));
                    oneTitlesI18N.set(8, String.valueOf(month) + "月份新增放款");
                }
            }
            if (this.twoTitles != null) {
                for (int i2 = 0; i2 < this.twoTitles.size(); i2++) {
                    twoTitlesI18N.add(LifeStandard.getResouceDisplayAt((String) this.twoTitles.get(i2), language));
                }
            }
            parser.writeToFile(oneTitlesI18N, twoTitlesI18N, recordList, this.outputFields, this.titleColWidthFormats, this.leftRightColMergeFormats, this.topBottomColMergeFormats, filePathName, this.encoding, this.titleField, this.leftRightColMergeNum);
            ctx.put("downloadFile", filePathName);
            return "0";
        } catch (Exception ex) {
            Trace.logError("LifeAction", "RZPT90001:报表下载处理出错", ex);
            throw new TranFailException("RZPT90001", "报表下载处理出错", false);
        }
    }

    private String getLanguage(Context context) {
        if (context == null) {
            return null;
        }
        String language = null;
        try {
            language = (String) context.getDataValue("session_language");
        } catch (GENEException unused) {
        }
        return language;
    }

    protected String getFileName(String fileType, String fileName) throws TranFailException {
        String rootPath = LifeStandard.getSelfDefineSettingsValue("tempDownloadDir");
        String folder = String.valueOf(LifeStandard.getServerTime("yyyyMMdd")) + LifeFile.DIR_SEPARATOR;
        LifeFile.makeMultiDirectory(rootPath, folder);
        String filePathName = String.valueOf(LifeStandard.getServerTime("HHmmssSSS")) + new Random().nextInt(1000) + fileName + '.' + fileType;
        return String.valueOf(rootPath) + folder + filePathName;
    }

    public List initFromContext(Map context, String iCollName) throws TranFailException {
        List recordList = new ArrayList();
        for (Map kcoll : (List) context.get(iCollName)) {
            recordList.add(kcoll);
        }
        return recordList;
    }

    public void setOutputFields(String outputFields) {
        List result = new ArrayList();
        StringTokenizer toke = new StringTokenizer(outputFields, FIELD_SEPERATOR);
        while (toke.hasMoreElements()) {
            String input = ((String) toke.nextElement()).trim();
            result.add(input);
        }
        this.outputFields = result;
    }

    public void setTitleColWidthFormats(String titleColWidthFormats) {
        List result = new ArrayList();
        StringTokenizer toke = new StringTokenizer(titleColWidthFormats, FIELD_SEPERATOR);
        while (toke.hasMoreElements()) {
            String input = ((String) toke.nextElement()).trim();
            result.add(input);
        }
        this.titleColWidthFormats = result;
    }

    public void setLeftRightColMergeFormats(String leftRightColMergeFormats) {
        List result = new ArrayList();
        StringTokenizer toke = new StringTokenizer(leftRightColMergeFormats, FIELD_SEPERATOR);
        while (toke.hasMoreElements()) {
            String input = ((String) toke.nextElement()).trim();
            result.add(input);
        }
        this.leftRightColMergeFormats = result;
    }

    public void setTopBottomColMergeFormats(String topBottomColMergeFormats) {
        List result = new ArrayList();
        StringTokenizer toke = new StringTokenizer(topBottomColMergeFormats, FIELD_SEPERATOR);
        while (toke.hasMoreElements()) {
            String input = ((String) toke.nextElement()).trim();
            result.add(input);
        }
        this.topBottomColMergeFormats = result;
    }

    public void setOneTitles(String oneTitles) {
        List title = new ArrayList();
        StringTokenizer toke = new StringTokenizer(oneTitles, FIELD_SEPERATOR);
        while (toke.hasMoreElements()) {
            String input = ((String) toke.nextElement()).trim();
            title.add(input);
        }
        this.oneTitles = title;
    }

    public void setTwoTitles(String twoTitles) {
        List title = new ArrayList();
        StringTokenizer toke = new StringTokenizer(twoTitles, FIELD_SEPERATOR);
        while (toke.hasMoreElements()) {
            String input = ((String) toke.nextElement()).trim();
            title.add(input);
        }
        this.twoTitles = title;
    }

    public void setICollName(String collName) {
        this.iCollName = collName;
    }

    public void setFileTypeField(String fileTypeField) {
        this.fileTypeField = fileTypeField;
    }

    public void setTitleField(String titleField) {
        this.titleField = titleField;
    }

    public void setFileNameField(String fileNameField) {
        this.fileNameField = fileNameField;
    }

    public void setEncoding(String encoding) {
        this.encoding = encoding;
    }

    public void setReportType(String reportType) {
        this.reportType = reportType;
    }

    public List getLeftRightColMergeNum() {
        return this.leftRightColMergeNum;
    }

    public void setLeftRightColMergeNum(String leftRightColMergeNum) {
        List result = new ArrayList();
        StringTokenizer toke = new StringTokenizer(leftRightColMergeNum, FIELD_SEPERATOR);
        while (toke.hasMoreElements()) {
            String input = ((String) toke.nextElement()).trim();
            result.add(input);
        }
        this.leftRightColMergeNum = result;
    }

    public static void main(String[] args) {
        System.out.println("20156676".substring(4, 6));
    }
}
